@@ -148,15 +148,13 @@ def egs_collect_games(egs_manifest_path):
 
             launch_executable = os.path.normpath(item["LaunchExecutable"])
 
-            # This causes trouble for some games
-            # (D:\Epic Games\RiME + /RiME/SirenGame/Binaries/Win64/RiME.exe = D:/RiME/SirenGame/Binaries/Win64/RiME.exe ???)
-            # complete_path = os.path.join(install_location, launch_executable)
+            if launch_executable[0] in "/\\":
+                # Sanitize bad paths. RiME uses
+                # "/RiME/SirenGame/Binaries/Win64/RiME.exe", which looks
+                # absolute but it isn't.
+                launch_executable = launch_executable[1:]
 
-            executable_path = (
-                os.path.normpath(install_location)
-                + os.path.sep
-                + os.path.normpath(launch_executable)
-            )
+            executable_path = os.path.join(install_location, launch_executable)
 
             # found by looking creating a shortcut on the desktop in the EGL and inspecting it
             # using the URI instead of executable_path allows some games with online services
@@ -199,7 +197,7 @@ def print_games(games):
 
 def filter_games(games):
     print(
-        "Which games do you want to install (blank = all, or comma seperated list of numbers from table)?"
+        "Which games do you want to install (blank = all, or comma separated list of numbers from table)?"
     )
     selection = input(": ").strip()
     if selection == "":
@@ -210,7 +208,12 @@ def filter_games(games):
     selected = list()
     for idx in selection:
         idx = idx.strip()
-        selected.append(games[int(idx) - 1])
+        try:
+            selected.append(games[int(idx) - 1])
+        except ValueError as e:
+            # Assuming: invalid literal for int() with base 10
+            print(f"Error: Expected number (1 for the first game) and not: '{idx}'")
+            return None
 
     print(f"Selected {len(selected)} games to install")
     return selected
@@ -277,11 +280,15 @@ def prompt_for_steam_account(accounts):
         return accounts[0].steamid
     elif choice in [account.steamid for account in accounts]:
         return choice
-    elif int(choice) <= len(accounts):
-        return accounts[int(choice) - 1].steamid
-    else:
-        print("You done messed up AARON")
-        exit(-1)
+
+    try:
+        idx = int(choice)
+        if idx <= len(accounts):
+            return accounts[idx - 1].steamid
+    except ValueError as e:
+        # Assuming: invalid literal for int() with base 10
+        print(f"Error: Expected number (1 for the first user) and not: '{choice}'")
+    return None
 
 
 def to_shortcut(game, use_uri):
@@ -313,9 +320,20 @@ def to_shortcut(game, use_uri):
     }
 
 
-def add_games_to_shortcut_file(
-    steam_path, steamid, games, skip_backup, use_uri
-):
+def add_games_to_shortcut_file(steam_path, steamid, games, skip_backup, use_uri):
+    """Add the given games to the shortcut file
+
+    Args:
+        steam_path (string): location of the root of the steam installation
+        steamid (string): numeric steamid to add shortcuts to
+        games ([GameDefinition]): games to add
+        skip_backup (bool): if we shouldn't back up the file
+        use_uri ([type]): if we should use the EGS uri, or the path to the executable
+
+    Returns:
+        (([string], integer), string): First element of tuple is a tuple of an array of "results" to display and the number of games added, 
+                                         The second is an error text if something went wrong
+    """
     if use_uri:
         print()
         print("⚠ ⚠ NOTICE: ⚠ ⚠")
@@ -334,11 +352,9 @@ def add_games_to_shortcut_file(
     )
 
     if not os.path.exists(shortcut_file_path):
-        print(f"Could not find shortcuts file at `{shortcut_file_path}`")
-        print(
-            "Make a shortcut in Steam (Library ➡ ➕ Add Game ➡ Add a Non-Steam Game...) first. Aborting."
-        )
-        exit(-2)
+        message = f"Could not find shortcuts file at `{shortcut_file_path}` \n Make a shortcut in Steam (Library ➡ ➕ Add Game ➡ Add a Non-Steam Game...) first. Aborting."
+        print(message)
+        return None, message
 
     # read in the shortcuts file
     with open(shortcut_file_path, "rb") as sf:
@@ -349,13 +365,16 @@ def add_games_to_shortcut_file(
     all_paths = set()
 
     for k, v in shortcuts["shortcuts"].items():
-        if "Exe" not in v:
+        exe_key = "Exe"
+        if exe_key not in v:
+            exe_key = "exe"
+        if exe_key not in v:
             print(
                 "Warning: Entry in shortcuts.vdf has no `Exe` field! Is this a malformed entry?"
             )
             print(v)
             continue
-        all_paths.add(v["Exe"])
+        all_paths.add(v[exe_key])
 
     # the shortcuts "list" is actually a dict of "index": value
     # find the last one so we can add on to the end
@@ -365,14 +384,15 @@ def add_games_to_shortcut_file(
     if len(all_indexes) == 0:
         last_index = 0
     else:
-        last_index = max(all_indexes)
+        last_index = max(int(idx) for idx in all_indexes)
 
+    game_results = []
     for game in games:
         shortcut = game.uri if use_uri else game.executable_path
         if shortcut in all_paths:
-            print(
-                f"Not creating shortcut for `{game.display_name}` since it already has one"
-            )
+            msg = f"{game.display_name}: Not creating shortcut since it already has one"
+            print(msg)
+            game_results.append(msg)
             continue
         last_index += 1
         shortcuts["shortcuts"][str(last_index)] = to_shortcut(game, use_uri)
@@ -380,8 +400,9 @@ def add_games_to_shortcut_file(
 
     print(f"Added {added} new games")
     if added == 0:
-        print(f"No need to update `shortcuts.vdf`")
-        return
+        msg = f"No need to update `shortcuts.vdf` - nothing new to add"
+        print(msg)
+        return None, msg
 
     if skip_backup:
         print("Not backing up `shortcuts.vdf` since you enjoy danger")
@@ -400,24 +421,35 @@ def add_games_to_shortcut_file(
     print("Updated `shortcuts.vdf` successfully!")
     print()
     print("➡   Restart Steam!")
+    return (game_results, added), None
 
 
 ####################################################################################################
 # Main
 
-if __name__ == "__main__":
+
+def main():
     args = parse_arguments()
     games = egs_collect_games(args.egs_manifests)
     print_games(games)
 
     if not args.all:
-        games = filter_games(games)
+        picks = None
+        while not picks:
+            picks = filter_games(games)
+        games = picks
 
     # add more GameDefinitions to games as needed...
 
     # Write shortcuts to steam!
     steamid = args.steamid
-    accounts = enumerate_steam_accounts(args.steam_path)
+    try:
+        accounts = enumerate_steam_accounts(args.steam_path)
+    except FileNotFoundError as e:
+        print(
+            f"Steam path not found: '{args.steam_path}'. Use --steam-path for non-standard installs."
+        )
+        return -1
 
     if len(accounts) == 1 and steamid != "":
         print(
@@ -442,10 +474,17 @@ if __name__ == "__main__":
             steamid = ""
 
     if steamid == "":
-        steamid = prompt_for_steam_account(accounts)
+        steamid = None
+        while not steamid:
+            steamid = prompt_for_steam_account(accounts)
 
     print(f"Installing shortcuts for SteamID `{steamid}`")
     add_games_to_shortcut_file(
         args.steam_path, steamid, games, args.live_dangerously, args.use_uri
     )
     print("Done.")
+    return 0
+
+
+if __name__ == "__main__":
+    main()
